------------------------------------------------------------------------------
-- SellableItemDrops - Logging your sellable item drops (TSM3 Module) 
------------------------------------------------------------------------------
-- Modules/Options.lua - build and show the option page
--
-- Author: Caraxe
--
-- Version v0.3.5
------------------------------------------------------------------------------

local addonName, addon = ...
local Options = addon:NewModule("Options")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local AceGUI = LibStub("AceGUI-3.0")
-- local LSM = LibStub("LibSharedMedia-3.0")
local private = {}

function Options:Load(container)
	local mvSourcesList = TSMAPI:GetPriceSources() or {}
	local daysOld = 14

	local soundValue = 1
	local soundList = {}
	
	-- LSM support is coming later, disabled for now
	LSM = nil
	
	if (LSM) then
		for index, soundName in pairs(LSM:List("sound")) do 
			soundList[index] = soundName
			if (addon.db.global.nwSound == LSM:Fetch("sound", soundName)) then
				soundValue = index
			end
			addon.Data:DebugPrintf("Found LSM #%s: %s", index, soundName)  
		end
	else 
		soundList[1] = "AuctionWindowOpen"
		addon.db.global.nwSound = "AuctionWindowOpen"
	end

	local page = {
		{
			type = "ScrollFrame",
			layout = "List",
			children = {
				{
					type = "InlineGroup",
					title = L["SellableItemDrops Options"],
					layout = "Flow",
					children = {
						{
							type = "Dropdown",
							label = L["Market Value Source"],
							settingInfo = {addon.db.global, "mvSource"},
							relativeWidth = 1,
							list = mvSourcesList,
							tooltip = L["Select you TSM3 market value source."],
						},
						{
							type = "Dropdown",
							label = L["Minimum Quality"],
							settingInfo = {addon.db.global, "minRarity"},
							list = addon.GUI.rarityList,
							tooltip = L["Select the minimum item quality to display."],
						},
						{
							type = "EditBox",
							label = L["Noteworthy Item Value"],
							settingInfo = {addon.db.global, "minNoteworthy"},
							acceptCustom = false,
							tooltip = L["Count items above this value and play a alarm sound."],
						},
						{
							type = "Dropdown",
							label = L["Time Format"],
							settingInfo = {addon.db.global, "timeFormat"},
							list = addon.GUI.timeFormat,
							tooltip = L["Select the format to display times."],
						},
						{
							type = "HeadingLine",
						},
						{
							type = "CheckBox",
							label = L["Use VendorSell for Grays"],
							settingInfo = { addon.db.global, "useVendorSellForGrays" },
							tooltip = L["If checked, the price source VendorSell is used for gray items instead of the market value, which is almost a really wrong value for grays."],
						},
						{
							type = "CheckBox",
							label = L["Use VendorSell for BOPs"],
							settingInfo = { addon.db.global, "useVendorSellForBOP" },
							tooltip = L["If checked, the price source VendorSell is used for BOP items and items without a market value."],
						},
						{
							type = "CheckBox",
							label = L["Discard Item Variants"],
							settingInfo = { addon.db.global, "useNotTheRealItemString" },
							tooltip = L["Use only the base items and discard the variants and upgrades of an item. " ..
								"This may lead to inacurate results, because the variants and upgrades could have different vendor sell values. " ..
								"You may switch this on for more compatibilty with Loot Appraiser. Turning from on to off or vice versa does " ..
								"only alter the listed database contnt and does not alter the current session Looted Item Value."],
						},
						{
							-- make the windows smaller during farming
							type = "CheckBox",
							label = L["Shrink the Frame"],
							settingInfo = { addon.db.global, "frScale" },
							callback = function(_, _, value) 
										if TSMMainFrame1 then
											if (value) then
												TSMMainFrame1.SetFrameScale(TSMMainFrame1, addon.GUI.frScaleValue)
											else
												TSMMainFrame1.SetFrameScale(TSMMainFrame1, 1)
											end
										end
									end,
							tooltip = L["If checked, the size of the "] .. addonName .. L[" frame is reduced."],
						},
						{
							type = "CheckBox",
							label = L["Next Lap resets all instances too"],
							settingInfo = { addon.db.global, "lpInstanceReset" },
							tooltip = L["When pressing Next Lap button or Rightclicking on minimap icon or LDB text an instance reset is done too."],
						},
						{
							type = "CheckBox",
							label = L["Show Player in List"],
							settingInfo = { addon.db.global, "shPlayer" },
							tooltip = L["If checked, show the player in the item list."],
						},
						{
							type = "HeadingLine",
						},
--						{
--							type = "Dropdown",
--							label = L["Noteworthy Sound"],
--							list = soundList,
--							value = soundValue,
--							relativeWidth = 1,
--							callback = function(_, _, value)
--								if (LSM) then
--									addon.db.global.nwSound = LSM:Fetch("sound", soundList[value])
--									addon.Data:DebugPrintf("Sound is %s", addon.db.global.nwSound)  
--								end
--							end,
--							tooltip = L["Select the sound file that is played if an item value is above the Noteworthy setting."],
--						},
					},
				},
			},
		},
	}

	TSMAPI.GUI:BuildOptions(container, page)
end

-- EOF
